@@ -120,7 +120,9 @@ class Line:
         # really, it would make sense that this is the identity, but we'll implement only when needed
         assert len(funcs) > 0, "You need to specify at least one function!"
         self.funcs = tuple(fnode(func, name) for name, func in named_funcs.items())
-        self.named_funcs = {name: fnode_func for name, fnode_func in zip(named_funcs, funcs)}
+        self.named_funcs = {name: fnode_func for name, fnode_func in zip(named_funcs, self.funcs)}
+        assert all(f == ff for f, ff in zip(self.funcs, self.named_funcs.values())), (
+            f"funcs and named_funcs are not aligned after merging")
         self.__signature__ = _signature_of_pipeline(*self.funcs)
         if pipeline_name is not None:
             self.__name__ = pipeline_name
