@@ -9,6 +9,7 @@ def incremental_str_maker(str_format="{:03.f}"):
 
     return mk_next_str
 
+
 unnamed_pipeline = incremental_str_maker(str_format="UnnamedPipeline{:03.0f}")
 unnamed_func_name = incremental_str_maker(str_format="unnamed_func_{:03.0f}")
 
@@ -17,6 +18,9 @@ def func_name(func):
     """The func.__name__ of a callable func, or makes and returns one if that fails.
     To make one, it calls unamed_func_name which produces incremental names to reduce the chances of clashing"""
     try:
-        return func.__name__
+        name = func.__name__
+        if name == '<lambda>':
+            return unnamed_func_name()
+        return name
     except AttributeError:
         return unnamed_func_name()
